@@ -1,11 +1,19 @@
-// Copyright (C) 2008-2016 National ICT Australia (NICTA)
+// SPDX-License-Identifier: Apache-2.0
 // 
-// This Source Code Form is subject to the terms of the Mozilla Public
-// License, v. 2.0. If a copy of the MPL was not distributed with this
-// file, You can obtain one at http://mozilla.org/MPL/2.0/.
-// -------------------------------------------------------------------
+// Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
+// Copyright 2008-2016 National ICT Australia (NICTA)
 // 
-// Written by Conrad Sanderson - http://conradsanderson.id.au
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+// http://www.apache.org/licenses/LICENSE-2.0
+// 
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+// ------------------------------------------------------------------------
 
 
 //! \addtogroup op_min
@@ -23,7 +31,7 @@ op_min::apply(Mat<typename T1::elem_type>& out, const Op<T1,op_min>& in)
   typedef typename T1::elem_type eT;
   
   const uword dim = in.aux_uword_a;
-  arma_debug_check( (dim > 1), "min(): parameter 'dim' must be 0 or 1");
+  arma_debug_check( (dim > 1), "min(): parameter 'dim' must be 0 or 1" );
   
   const quasi_unwrap<T1> U(in.m);
   const Mat<eT>& X = U.M;
@@ -158,17 +166,16 @@ op_min::apply(Cube<typename T1::elem_type>& out, const OpCube<T1,op_min>& in)
   arma_debug_check( (dim > 2), "min(): parameter 'dim' must be 0 or 1 or 2" );
   
   const unwrap_cube<T1> U(in.m);
-  const Cube<eT>& X =   U.M;
   
-  if(&out != &X)
+  if(U.is_alias(out) == false)
     {
-    op_min::apply_noalias(out, X, dim);
+    op_min::apply_noalias(out, U.M, dim);
     }
   else
     {
     Cube<eT> tmp;
     
-    op_min::apply_noalias(tmp, X, dim);
+    op_min::apply_noalias(tmp, U.M, dim);
     
     out.steal_mem(tmp);
     }
